==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebRowToggleEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebRowToggleEventArgsDetailDescription } from "./WebRowToggleEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebRowToggleEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebRowToggleEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebRowToggleEventArgsDetailDescriptionMetadata.a == null) {
                WebRowToggleEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebRowToggleEventArgsDetailDescriptionMetadata.c(WebRowToggleEventArgsDetailDescriptionMetadata.a);
            }
            if (a.k(WebRowToggleEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebRowToggleEventArgsDetailDescriptionMetadata.a);
        }
        static c(a) {
            WebBaseEventArgsDetailDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:RowToggleEventArgsDetail");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("RowID", "Unknown");
            a.item("Expanded", "Boolean");
            a.item("Cancel", "Boolean");
        }
        static d(a) {
            WebRowToggleEventArgsDetailDescriptionMetadata.b(a);
            a.ad("WebRowToggleEventArgsDetail", () => new WebRowToggleEventArgsDetailDescription());
            a.ac("WebRowToggleEventArgsDetail", WebRowToggleEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebRowToggleEventArgsDetailDescriptionMetadata.$t = markType(WebRowToggleEventArgsDetailDescriptionMetadata, 'WebRowToggleEventArgsDetailDescriptionMetadata');
    WebRowToggleEventArgsDetailDescriptionMetadata.a = null;
    return WebRowToggleEventArgsDetailDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebRowToggleEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebRowToggleEventArgsDetailDescription } from "./WebRowToggleEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebRowToggleEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebRowToggleEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebRowToggleEventArgsDetailDescriptionMetadata.a == null) {
                WebRowToggleEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebRowToggleEventArgsDetailDescriptionMetadata.c(WebRowToggleEventArgsDetailDescriptionMetadata.a);
            }
            if (a.k(WebRowToggleEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebRowToggleEventArgsDetailDescriptionMetadata.a);
        }
        static c(a) {
            WebBaseEventArgsDetailDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:RowToggleEventArgsDetail");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("RowID", "Unknown");
            a.item("RowKey", "Unknown");
            a.item("Expanded", "Boolean");
            a.item("Cancel", "Boolean");
        }
        static d(a) {
            WebRowToggleEventArgsDetailDescriptionMetadata.b(a);
            a.ae("WebRowToggleEventArgsDetail", () => new WebRowToggleEventArgsDetailDescription());
            a.ad("WebRowToggleEventArgsDetail", WebRowToggleEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebRowToggleEventArgsDetailDescriptionMetadata.$t = markType(WebRowToggleEventArgsDetailDescriptionMetadata, 'WebRowToggleEventArgsDetailDescriptionMetadata');
    WebRowToggleEventArgsDetailDescriptionMetadata.a = null;
    return WebRowToggleEventArgsDetailDescriptionMetadata;
})();
